Learn R Programming

survAH (version 1.2.0)

cm214_pfs: Sample Reconstructed Data of CheckMate214 Study

Description

The progression-free survival data reconstructed from the publication of the CheckMate214 study.

Usage

data(cm214_pfs)

Arguments

Format

A dataset containing 3 columns:

time

the time-to-event variable (the time unit is month)

status

the event indicator (1=event, 0=censor)

arm

the treatment indicator (1=treatment, 0=control)

Details

This is a reconstructed patient-level data from the results reported by Motzer et al.(2018) <doi:10.1056/NEJMoa1712126>. The data consists of 847 patients with previously untreated clear-cell advanced renal-cell carcinoma; 425 for the nivolumab plus ipilimumab group (treatment) and 422 for the sunitinib group (control).