| ah1 | R Documentation |
Calculates the average hazard with survival weight and the corresponding asymptotic confidence interval for a single sample.
ah1(time, status, tau, conf.int=0.95)
time |
A numeric vector of follow-up times for right-censored data. |
status |
A numeric vector indicating the event status; 1 = event occurred, 0 = right censored. |
tau |
A scalar specifying the end time point ( |
conf.int |
A numeric value specifying the confidence level for confidence intervals. The default is |
It also provides the log-transformed t-year event rate and restricted mean survival time (RMST) along with their variances as intermediate products. Note that the confidence intervals for the t-year event rate and RMST are based on log-scale values. As a result, the confidence intervals may differ slightly from those generated by the surv2sampleComp or survRM2 packages.
An object of class ah1, which contains the following components:
need_stop |
Logical indicator. If |
tau |
The truncation time point used in the analysis. |
result1 |
Estimated average hazard. |
Hajime Uno, Miki Horiguchi
Uno H and Horiguchi M. Ratio and difference of average hazard with survival weight: new measures to quantify survival benefit of new therapy. Statistics in Medicine. 2023;1-17. <doi:10.1002/sim.9651>
#====================================================================
# cm214_pfs: The sample reconstructed data of the CheckMate214 study.
# The code below reproduces the results reported by
# Uno and Horiguchi (StatMed; 2023) in Table 6.
#====================================================================
D = cm214_pfs
time = D$time
status = D$status
tau = 21
b = ah1(time=time, status=status, tau=tau, conf.int=0.95)
print(b)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.